PeerIpKeyExtractor

Struct PeerIpKeyExtractor 

pub struct PeerIpKeyExtractor;
A [KeyExtractor] that uses peer IP as key. This is the default key extractor and it may no do want you want.

Warning: this key extractor enforces rate limiting based on the peer IP address.

This means that if your app is deployed behind a reverse proxy, the peer IP address will always be the proxy’s IP address. In this case, rate limiting will be applied to all incoming requests as if they were from the same user.

If this is not the behavior you want, you may:

  • Use the SmartIpKeyExtractor to get the IP from the Forwarded or X-Forwarded-For headers that most proxies set
  • implement your own [KeyExtractor] that tries to get IP from the Forwarded or X-Forwarded-For headers that most reverse proxies set
  • make absolutely sure that you only trust these headers when the peer IP is the IP of your reverse proxy (otherwise any user could set them to fake its IP)