SmartIpKeyExtractor

Struct SmartIpKeyExtractor 

pub struct SmartIpKeyExtractor;
A [KeyExtractor] that tries to get the client IP address from the x-forwarded-for, x-real-ip, and forwarded headers in that order. Falls back to the peer IP address.

Warning: Only use this key extractor if you can ensure these headers are being set by a trusted provider.**.

This is a sane default for an app running behind a reverse proxy, with the caveat that one must be careful of ths source of the headers. It will fall back to the peer IP address if the headers are not present, which would set a global rate limit if behind a reverse proxy. If it fails to find any of the headers or the peer IP, it will error out.