pub struct ModifyZoneRequest {
pub also_notify: Option<Vec<String>>,
pub allow_transfer: Option<Vec<String>>,
pub allow_update: Option<Vec<String>>,
}Expand description
Request to modify a zone configuration
Fields
also_notify: Option<Vec<String>>IP addresses of secondary servers to notify when zone changes (BIND9 also-notify) Example: [“10.244.2.101”, “10.244.2.102”]
allow_transfer: Option<Vec<String>>IP addresses allowed to transfer the zone (BIND9 allow-transfer) Example: [“10.244.2.101”, “10.244.2.102”]
allow_update: Option<Vec<String>>IP addresses allowed to update the zone dynamically (BIND9 allow-update) Example: [“10.244.2.101”, “10.244.2.102”]