pub async fn modify_zone(
__arg0: State<AppState>,
__arg1: Path<String>,
__arg2: Json<ModifyZoneRequest>,
) -> Result<Json<ZoneResponse>, ApiError>Expand description
Modify a zone configuration
This endpoint allows updating zone configuration parameters such as
also-notify and allow-transfer IP addresses without recreating the zone.
It uses the rndc modzone command to dynamically update the zone configuration.